import React from "react";
import { useCallback, useEffect, useState } from "react";
import { useLogin, useLogout, useUser } from "./SwaggerApi";
import { userContext } from "@ess-ics/ce-ui-common";

export function UserProvider({ children }) {
  function onLoginError(message) {
    setLoginError(message);
  }

  const [user, getUser, resetUser, userLoading] = useUser();
  const [loginError, setLoginError] = useState();
  const [loginResponse, loginFcn /* reset*/, , loginLoading] =
    useLogin(onLoginError);
  const [logoutFcn, logoutLoading] = useLogout();
  const [initialized, setInitialized] = useState(false);

  const resetLoginError = useCallback(
    () => setLoginError(null),
    [setLoginError]
  );

  useEffect(getUser, [loginResponse, getUser]);

  const logout = useCallback(async () => {
    resetUser();
    logoutFcn();
  }, [resetUser, logoutFcn]);

  const login = useCallback(
    (username, password) => {
      loginFcn(username, password);
    },
    [loginFcn]
  );

  const loading = Boolean(loginLoading || userLoading || logoutLoading);

  const createValue = useCallback(() => {
    return {
      user: user?.userInfo,
      userRoles: user?.userRoles,
      login,
      loginError,
      resetLoginError,
      logout
    };
  }, [
    user?.userInfo,
    user?.userRoles,
    login,
    loginError,
    resetLoginError,
    logout
  ]);

  const [value, setValue] = useState(createValue());

  useEffect(() => {
    if (!loading) {
      setInitialized(true);
    }
  }, [loading]);

  useEffect(() => {
    if (!loading) {
      setValue(createValue());
    }
  }, [loading, setValue, createValue]);

  return (
    initialized && (
      <userContext.Provider value={value}>{children}</userContext.Provider>
    )
  );
}
