import React from "react";
import { Table } from "@ess-ics/ce-ui-common";
import { Grid, Link } from "@mui/material";
import { noWrapText } from "../common/Helper";
import { JobStatusIcon, JobTypeIcon } from "./JobIcons";
import { formatDate } from "../common/Helper";

const jobLogColumns = [
  {
    field: "type",
    headerName: "Type",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  { field: "ioc", headerName: "IOC name", width: "15ch", sortable: false },
  { field: "version", headerName: "Revision", width: "10ch", sortable: false },
  { field: "host", headerName: "Host", width: "15ch", sortable: false },
  { field: "user", headerName: "User", width: "10ch", sortable: false },
  {
    field: "start",
    headerName: "Time",
    width: "15ch",
    sortable: false,
    headerAlign: "right",
    textAlign: "right"
  }
];

function createTableRow(job, colorStyle) {
  return {
    id: job.id,
    type: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <JobTypeIcon
          type={job.type}
          colorStyle={colorStyle}
        />
      </Grid>
    ),
    status: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <JobStatusIcon status={job.status} />
      </Grid>
    ),
    ioc: <Link href={`/iocs/${job.iocId}`}>{noWrapText(job.iocName)}</Link>,
    version: (
      <Link href={`/jobs/${job?.id}`}>
        {noWrapText(job.sourceVersionShort ?? job.gitReference)}
      </Link>
    ),
    host: (
      <Link href={`/hosts/${job?.host?.externalHostId}`}>
        {noWrapText(job.host?.hostName ?? null)}
      </Link>
    ),
    network: noWrapText(job.host?.network ?? null),
    user: (
      <Link href={`/user/${job.createdBy}`}>{noWrapText(job.createdBy)}</Link>
    ),
    start: noWrapText(formatDate(job.createdAt)),
    deploymentFailed: job.status === "FAILED" || job.status === "ERROR",
    jobType: job.type,
    iocId: job.iocId,
    deploymentId: job.deploymentId
  };
}

function createTableRowJobLog(job) {
  return createTableRow(job, "black");
}

export function JobTable({
  jobs,
  rowType = "jobLog",
  pagination,
  onPage,
  loading
}) {
  const tableTypeSpecifics = {
    jobLog: [jobLogColumns, createTableRowJobLog]
  };

  const [columns, createRow] = tableTypeSpecifics[rowType];

  return (
    <Table
      columns={columns}
      rows={jobs?.map((job) => createRow(job))}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
      autoHeight
    />
  );
}
