import React from "react";
import { Card, CardHeader } from "@mui/material";
import { useState, useEffect } from "react";
import { useIOCSearch } from "../../../api/SwaggerApi";
import { IOCAsyncList } from "../../IOC/IOCAsyncList";
import { initRequestParams } from "../Helper";
import { usePagination } from "../../../hooks/pagination";

export function UserIocList({ userName }) {
  const [iocs, getIocs, , loading] = useIOCSearch();
  const [iocList, setIocList] = useState([]);

  // Sync manipulatable ioc list copy
  useEffect(() => {
    setIocList(iocs.iocList);
  }, [iocs, setIocList]);

  const rowsPerPage = [20, 50];
  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: rowsPerPage,
    initLimit: rowsPerPage[0],
    initPage: 0
  });

  // update pagination whenever search result total pages change
  useEffect(() => {
    setPagination({ totalCount: iocs.totalCount ?? 0 });
  }, [setPagination, iocs.totalCount]);

  // Request more results when pagination changes
  useEffect(() => {
    let requestParams = initRequestParams(pagination);

    requestParams.created_by = userName;

    getIocs(requestParams);
  }, [getIocs, pagination, userName]);

  // Invoked by Table on change to pagination
  const onPage = (params) => {
    setPagination(params);
  };

  return (
    <Card>
      <CardHeader
        title={`IOCs registered by ${userName}`}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <IOCAsyncList
        iocs={iocList}
        setIocs={setIocList}
        loading={loading}
        rowType="explore"
        pagination={pagination}
        onPage={onPage}
      />
    </Card>
  );
}
