import React, { useCallback, useRef, useEffect } from "react";
import { LinearProgress, Typography, Container } from "@mui/material";
import { useJobLogById } from "../../api/SwaggerApi";
import { Console } from "../common/Console/Console";
import { useSafePolling } from "../../hooks/Polling";

const LOG_POLL_INTERVAL = 5000;
export function DeploymentJobOutput({ deploymentJob }) {
  const [log, getLogById /* reset*/, , logLoading] = useJobLogById();
  const finalResultsNeeded = useRef(true);

  useEffect(() => {
    finalResultsNeeded.current = true;
  }, [deploymentJob.id]);

  const getLog = useCallback(() => {
    if (!deploymentJob.finished || finalResultsNeeded.current) {
      getLogById(deploymentJob.id);
      finalResultsNeeded.current = !deploymentJob.finished;
    }
  }, [deploymentJob.finished, deploymentJob.id, getLogById]);
  useSafePolling(getLog, logLoading, LOG_POLL_INTERVAL);

  const dataReady = useCallback(() => {
    return deploymentJob?.started;
  }, [deploymentJob?.started]);

  let header = (
    <div
      style={{
        display: "flex",
        alignItems: "center"
      }}
    >
      <Typography variant="overline">DURATION: </Typography>
      <Typography
        style={{
          marginLeft: "6px"
        }}
      >
        {log?.elapsed.toFixed(0)} s
      </Typography>
    </div>
  );

  return (
    <Container maxWidth="xl">
      {log ? (
        <div
          style={{
            width: "100%"
          }}
        >
          <Console
            html={log.stdoutHtml}
            dataReady={dataReady}
            title="AWX job details"
            dialogHeader={header}
          />
        </div>
      ) : (
        <div style={{ width: "100%" }}>
          <LinearProgress color="primary" />
        </div>
      )}
    </Container>
  );
}
