import React, { useEffect, useContext, useState } from "react";
import { IOCDetailsView } from "./IOCDetailsView";
import { LinearProgress } from "@mui/material";
import NotFoundView from "../../components/navigation/NotFoundView/NotFoundView";
import { onFetchEntityError } from "../../components/common/Helper";
import { useIOC } from "../../api/SwaggerApi";
import { userContext } from "@ess-ics/ce-ui-common/dist/contexts/User";
import useUrlState from "@ahooksjs/use-url-state";

export function IOCDetailsContainer({ id }) {
  const { user } = useContext(userContext);
  const [urlState] = useUrlState();
  const [error, setError] = useState(null);

  const [ioc, getIOC /* reset*/, , loading] = useIOC(id, (m, s) => {
    // handle error code 404, and define custom message on the UI because BE sends back generic error message
    onFetchEntityError(m, s, setError);
  });

  useEffect(() => {
    // user logs in => clear error message, and try to re-request userInfo
    if (user) {
      setError(null);
    } else if (!user && urlState?.tab) {
      // user is not logged in => show a message
      setError({ message: "Unauthorized", status: "401" });
    }
  }, [urlState, user]);

  return (
    <>
      {error ? (
        <NotFoundView
          message={error?.message}
          status={error?.status}
        />
      ) : ioc ? (
        <IOCDetailsView
          ioc={ioc}
          getIOC={getIOC}
          loading={loading}
        />
      ) : (
        <LinearProgress color="primary" />
      )}
    </>
  );
}
