import React, { useContext, useEffect, useState } from "react";
import { UserPageView } from "./UserPageView";
import { LinearProgress } from "@mui/material";
import NotFoundView from "../../components/navigation/NotFoundView/NotFoundView";
import { useUserInfo } from "../../api/SwaggerApi";
import { userContext } from "@ess-ics/ce-ui-common/dist/contexts/User";

export function UserDetailsContainer({ userName }) {
  const { user } = useContext(userContext);
  const [error, setError] = useState(null);

  const [userInfo, getUserInfo, ,] = useUserInfo(userName, (m, s) => {
    // log error message for userInfo
    console.warn(m);

    // user not found
    if (s === 404) {
      setError({ message: "Page not found", status: `${s}` });
      // do not show snackbar error
      return false;
    }

    // user doesn't have permission to fetch userInfo
    if (s === 401) {
      setError({ message: "Unauthorized", status: `${s}` });
      // do not show snackbar error
      return false;
    }
  });

  useEffect(() => {
    // user logs in => clear error message, and try to re-request userInfo
    if (user) {
      setError(null);
    } else {
      // user is not logged in => show a message
      setError({ message: "Unauthorized", status: "401" });
    }
  }, [user]);

  useEffect(() => {
    // request userInfo only if user is logged in
    if (user) {
      getUserInfo();
    }
  }, [getUserInfo, userName, user]);

  return (
    <>
      {error ? (
        <NotFoundView
          status={error?.status ?? "404"}
          message={error?.message}
        />
      ) : user?.loginName === userName ? (
        <UserPageView
          userName={userName}
          user={user}
          userInfo={userInfo}
        />
      ) : (
        <LinearProgress color="primary" />
      )}
    </>
  );
}
